@@ -23,11 +23,11 @@ FilmAffinity::Movie - Perl interface to FilmAffinity
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 =head1 SYNOPSIS
 
@@ -39,7 +39,7 @@ Retrieve information about a filmaffinity movie
       id    => $movieID,
       delay => $delay || 5,
     );
-    
+
     $movie->parse();
 
 Via the command-line program filmaffinity-get-movie-info.pl
@@ -355,7 +355,7 @@ sub parsePage {
   $self->p_findVotes();
   $self->country( $self->tree->findvalue( $XPATH_COUNTRY ) );
   $self->cover( $self->tree->findvalue( $XPATH_COVER ) );
-  $self->title( $self->tree->findvalue( $XPATH_TITLE ) );
+  $self->title( trim($self->tree->findvalue( $XPATH_TITLE )) );
 
   $self->tree->delete();
   return;
@@ -540,4 +540,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-1; # End of FilmAffinity::Movie
\ No newline at end of file
+1; # End of FilmAffinity::Movie
